@@ -12,3 +12,6 @@ class _tpl_curve_generator_correlated_data(_tpl_curve_generator):
   def _get_draw(self):
     color = "=%s" % self.curve.color.get_value() if self.curve.color.get_value() is not None else ""
     return "draw%s," % color
+
+  def _get_marks(self):
+    return "% marks,"
